==> haskell-floatinghex-0.4-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: FloatingHex
version: 0.4
id: FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf
key: FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf
license: BSD-3-Clause
copyright: Levent Erkok
maintainer: erkokl@gmail.com
author: Levent Erkok
synopsis: Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.
    .
    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.
    .
    For details, please see: <http://github.com/LeventErkok/FloatingHex/>
category: Tools
abi: 605bb1bfe23344bd45c4ab3810667816
exposed: True
exposed-modules:
    Data.Numbers.FloatingHex
import-dirs: /usr/lib/ghc-8.4.3/site-local/FloatingHex-0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/FloatingHex-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/FloatingHex-0.4
hs-libraries: HSFloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html: /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floatinghex-0.4-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: FloatingHex
version: 0.4
id: FloatingHex-0.4-7UrngnwzVEHuk3w2MDnq3
key: FloatingHex-0.4-7UrngnwzVEHuk3w2MDnq3
license: BSD-3-Clause
copyright: Levent Erkok
maintainer: erkokl@gmail.com
author: Levent Erkok
synopsis: Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.
    .
    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.
    .
    For details, please see: <http://github.com/LeventErkok/FloatingHex/>
category: Tools
abi: da0b71d6568b60ae7edac89c3b0b05ed
exposed: True
exposed-modules:
    Data.Numbers.FloatingHex
import-dirs: /usr/lib/ghc-8.6.1/site-local/FloatingHex-0.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/FloatingHex-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/FloatingHex-0.4
hs-libraries: HSFloatingHex-0.4-7UrngnwzVEHuk3w2MDnq3
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html: /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
